using System;
using Autoscribe.Lyons.GeneralService;
using System.ServiceModel;
using System.ServiceModel.Channels;
using Autoscribe.Lyons.OFACServiceContract;

namespace ofacDemo.Wrapper
{
    public class OFACWrapper : IOFACWrapper
    {
        public const string CFG_OFAC_SVC_END_POINT_CONFIGURATION_NAME = "OFACServiceRest";
        public LogonResult Logon(int companyId, string username, string password)
        {
            LogonResult result = null;
            try
            {
                using (ChannelFactory<IOFACService> fact = new ChannelFactory<IOFACService>(CFG_OFAC_SVC_END_POINT_CONFIGURATION_NAME))
                {
                    IOFACService svc = fact.CreateChannel();
                    result = svc.Logon(companyId, username, password);
                }
            }
            catch (FaultException fe)
            {
                MessageFault mf = fe.CreateMessageFault();
                string errorDetail = null;
                if (mf.HasDetail)
                {
                    ErrorResult errorData = mf.GetDetail<ErrorResult>();
                    errorDetail = errorData.ErrorMesssage;
                    Console.WriteLine(" --> Web Error: {0}", errorDetail);
                }
                result = new LogonResult(errorDetail);
            }
            catch (Exception ex)
            {
                Console.WriteLine(" --> Internal Error: {0}", ex.Message);
                result = new LogonResult("Internal Error");
            }
            return result;
        }
        public void Logoff(string token)
        {
            try
            {
                using (ChannelFactory<IOFACService> fact = new ChannelFactory<IOFACService>(CFG_OFAC_SVC_END_POINT_CONFIGURATION_NAME))
                {
                    IOFACService svc = fact.CreateChannel();
                    svc.Logoff(token);
                }

            }
            catch (FaultException fe)
            {
                MessageFault mf = fe.CreateMessageFault();
                string errorDetail = null;
                if (mf.HasDetail)
                {
                    ErrorResult errorData = mf.GetDetail<ErrorResult>();
                    errorDetail = errorData.ErrorMesssage;
                    Console.WriteLine(" --> Web Error: {0}", errorDetail);
                }                
            }
            catch (Exception ex)
            {
                Console.WriteLine(" --> Internal Error: {0}", ex.Message);
            }
        }

        public EntityListResult OFACLogonScanName(int companyID, string userName, string password, string name)
        {
            EntityListResult result = null;
            try
            {
                using (ChannelFactory<IOFACService> fact = new ChannelFactory<IOFACService>(CFG_OFAC_SVC_END_POINT_CONFIGURATION_NAME))
                {
                    IOFACService svc = fact.CreateChannel();
                    result = svc.OFACLogonScanName(companyID, userName, password, name);
                }
            }
            catch (FaultException fe)
            {
                MessageFault mf = fe.CreateMessageFault();
                string errorDetail = null;
                if (mf.HasDetail)
                {
                    ErrorResult errorData = mf.GetDetail<ErrorResult>();
                    errorDetail = errorData.ErrorMesssage;
                    Console.WriteLine(" --> Web Error: {0}", errorDetail);
                }
                result = new EntityListResult(errorDetail);
            }
            catch (Exception ex)
            {
                Console.WriteLine(" --> Internal Error: {0}", ex.Message);
                result = new EntityListResult("Internal Error");
            }
            return result;
        }
        public EntityListResult OFACScanName(string token, string name)
        {
            EntityListResult result = null;
            try
            {
                using (ChannelFactory<IOFACService> fact = new ChannelFactory<IOFACService>(CFG_OFAC_SVC_END_POINT_CONFIGURATION_NAME))
                {
                    IOFACService svc = fact.CreateChannel();
                    result = svc.OFACScanName(token, name);
                }
            }
            catch (FaultException fe)
            {
                MessageFault mf = fe.CreateMessageFault();
                string errorDetail = null;
                if (mf.HasDetail)
                {
                    ErrorResult errorData = mf.GetDetail<ErrorResult>();
                    errorDetail = errorData.ErrorMesssage;
                    Console.WriteLine(" --> Web Error: {0}", errorDetail);
                }
                result = new EntityListResult(errorDetail);
            }
            catch (Exception ex)
            {
                Console.WriteLine(" --> Internal Error: {0}", ex.Message);
                result = new EntityListResult("Internal Error");
            }
            return result;
        }
        public EntityListResult OFACScanCountry(string token, string name, string country)
        {
            EntityListResult result = null;
            try
            {
                using (ChannelFactory<IOFACService> fact = new ChannelFactory<IOFACService>(CFG_OFAC_SVC_END_POINT_CONFIGURATION_NAME))
                {
                    IOFACService svc = fact.CreateChannel();
                    result = svc.OFACScanCountry(token, name, country);
                }
            }
            catch (FaultException fe)
            {
                MessageFault mf = fe.CreateMessageFault();
                string errorDetail = null;
                if (mf.HasDetail)
                {
                    ErrorResult errorData = mf.GetDetail<ErrorResult>();
                    errorDetail = errorData.ErrorMesssage;
                    Console.WriteLine(" --> Web Error: {0}", errorDetail);
                }
                result = new EntityListResult(errorDetail);
            }
            catch (Exception ex)
            {
                Console.WriteLine(" --> Internal Error: {0}", ex.Message);
                result = new EntityListResult("Internal Error");
            }
            return result;
        }
        public CountryListResult GetCountryList(string token)
        {
            CountryListResult result = null;
            try
            {
                using (ChannelFactory<IOFACService> fact = new ChannelFactory<IOFACService>(CFG_OFAC_SVC_END_POINT_CONFIGURATION_NAME))
                {
                    IOFACService svc = fact.CreateChannel();
                    result = svc.GetCountryList(token);
                }
            }
            catch (FaultException fe)
            {
                MessageFault mf = fe.CreateMessageFault();
                string errorDetail = null;
                if (mf.HasDetail)
                {
                    ErrorResult errorData = mf.GetDetail<ErrorResult>();
                    errorDetail = errorData.ErrorMesssage;
                    Console.WriteLine(" --> Web Error: {0}", errorDetail);
                }
                result = new CountryListResult(errorDetail);
            }
            catch (Exception ex)
            {
                Console.WriteLine(" --> Internal Error: {0}", ex.Message);
                result = new CountryListResult("Internal Error");
            }
            return result;
        }
        public FullEntityListResult OFACScanNameFullRecord(string token, string name, string country)
        {
            FullEntityListResult result = null;
            try
            {
                using (ChannelFactory<IOFACService> fact = new ChannelFactory<IOFACService>(CFG_OFAC_SVC_END_POINT_CONFIGURATION_NAME))
                {
                    IOFACService svc = fact.CreateChannel();
                    result = svc.OFACScanNameFullRecord(token, name, country);
                }
            }
            catch (FaultException fe)
            {
                MessageFault mf = fe.CreateMessageFault();
                string errorDetail = null;
                if (mf.HasDetail)
                {
                    ErrorResult errorData = mf.GetDetail<ErrorResult>();
                    errorDetail = errorData.ErrorMesssage;
                    Console.WriteLine(" --> Web Error: {0}", errorDetail);
                }
                result = new FullEntityListResult(errorDetail);
            }
            catch (Exception ex)
            {
                Console.WriteLine(" --> Internal Error: {0}", ex.Message);
                result = new FullEntityListResult("Internal Error");
            }
            return result;
        }
    }
}
